
# q-expansion of newform 429.2.e.c, downloaded from the LMFDB on 26 April 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 429
weight = 2
poly_data = [64, 0, 404, 0, 273, 0, -924, 0, 1300, 0, -666, 0, 164, 0, -20, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[1865592, 0, -305344, 0, -250803, 0, 779299, 0, -504639, 0, 141809, 0, -18889, 0, 1017, 0], 695368], [[0, 16866948, 0, 3745023, 0, -28056790, 0, 41344590, 0, -21171500, 0, 5186482, 0, -628770, 0, 31233], 695368], [[1437494, 0, 3413416, 0, -7059146, 0, 8332329, 0, -4060171, 0, 976398, 0, -117329, 0, 5799, 0], 173842], [[-9249288, 0, -23948824, 0, 51028693, 0, -56418201, 0, 26657365, 0, -6309143, 0, 751451, 0, -36955, 0], 695368], [[10837864, 0, 22684152, 0, -52062909, 0, 59716185, 0, -28599597, 0, 6814631, 0, -814827, 0, 40155, 0], 695368], [[-13405760, 0, -29371920, 0, 66859611, 0, -78591519, 0, 37939335, 0, -9069441, 0, 1086197, 0, -53617, 0], 695368], [[13045736, -6116828, 30533344, -1236901, -65914896, 10393614, 75511150, -15174808, -36253462, 7753568, 8656492, -1903314, -1036686, 231812, 51170, -11595], 695368], [[-2542687, 0, -5926628, 0, 12949151, 0, -14711623, 0, 7033280, 0, -1675924, 0, 200507, 0, -9893, 0], 86921], [[6255548, 0, 15293776, 0, -32342229, 0, 36994087, 0, -17787087, 0, 4256369, 0, -511003, 0, 25297, 0], 173842], [[0, 40253716, 0, 94637175, 0, -203744128, 0, 230644536, 0, -110207086, 0, 26258800, 0, -3141792, 0, 155031], 695368], [[0, 46444516, 0, 117626671, 0, -255556234, 0, 289581422, 0, -138302044, 0, 32931622, 0, -3937730, 0, 194169], 695368], [[0, -56266252, 0, -122356757, 0, 267041610, 0, -310245654, 0, 149903292, 0, -35936294, 0, 4316546, 0, -213619], 695368], [[-2535072, 72462192, -9173224, 166286064, 18241397, -360935116, -19161083, 415064900, 8911133, -199597198, -2098071, 47711512, 249485, -5719412, -12255, 282598], 695368], [[-4760688, -68836696, -7706456, -164164102, 19436915, 357404278, -23020751, -407951240, 11101645, 195442680, -2652829, -46621406, 317885, 5581644, -15719, -275554], 695368], [[0, 110595980, 0, 259657357, 0, -560454494, 0, 636294706, 0, -304468532, 0, 72609066, 0, -8692814, 0, 429155], 695368]]

hecke_ring_character_values = [[287, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [79, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [67, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 1, 0, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 1, -1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1], [0, 2, 0, -1, 0, 0, -2, 0, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1], [0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0], [0, 0, 0, 3, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 0, 0, -1, -1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 2, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 1, -1, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0, -2, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, 0, 0, 0], [0, -2, 0, 2, 0, 0, 4, 0, -2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0, -3, -2, 0, 0, 0, 0, 1, 1, 0], [0, 0, 0, 3, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, -2, 2, 0, 0, 0], [0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0], [0, 2, 0, -1, 0, 0, -2, 0, 1, 0, 0, 0, 0, -2, 2, 1], [0, 0, 0, 0, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -2, 0, 1, 0, 0, 2, 0, -1, 0, 0, 0, 0, 2, -2, -2], [0, -4, 0, 3, 0, 0, 6, 0, -3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 5, -3, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0], [0, 0, 0, -2, 0, 0, 0, 1, -1, 0, 0, 0, 0, 3, 3, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, -3, -3, 0], [0, 0, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 6, 0, -1, 0, 0, -2, 0, 1, 0, 0, 0, 0, 0, 0, 0], [-6, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0], [0, 0, 0, -2, 0, 0, 0, 0, -8, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1], [0, 0, 0, 0, -1, 5, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0], [2, 0, 0, 0, 5, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -2, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -6, -6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -2, 0, 0, 0, -1, -3, 0, 0, 0, 0, 5, 5, 0], [0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 3, 0, 0, 0, 0, -3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0], [0, -2, 0, 1, 0, 0, 2, 0, -1, 0, 0, 0, 0, 2, -2, -1], [0, 0, 0, -10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 4, 0, 1, 0, 0, 2, 0, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -7, -1, 0, 0, 0, -8, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 6, -10, 0, 0, 0, -4, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -4], [0, 0, 0, 0, -6, -2, 0, 0, 0, -8, 0, 0, 0, 0, 0, 0], [0, 4, 0, -2, 0, 0, -4, 0, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 2, 0, 0, 0, -2, 0, 0, 0, 0, 0, -2, -2, 0], [0, 0, 0, 6, 0, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 0, 0, -1, -1, 0], [0, 0, 0, 13, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0], [0, 4, 0, -4, 0, 0, -8, 0, 4, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 6, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0], [22, 0, 0, 0, -3, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 2, -2, 0, 0, 0], [0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -1, 0, 0, 0, 4, 3, 0, 0, 0, 0, -2, -2, 0], [0, -2, 0, 1, 0, 0, 2, 0, -1, 0, 0, 0, 0, 2, -2, -2], [0, -4, 0, -1, 0, 0, -2, 0, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, -2, 2, 0, 0, 0], [0, 0, 0, 9, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0], [-12, 0, 0, 0, 9, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 2, 0, 0, 0, -2, 0, 0, 0, 0, 0, -2, -2, 0], [0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, -3, 3, 0, 0, 0], [0, 0, 0, 0, -1, 3, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0], [0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, -2, -2, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 3, -3, 0, 0, 0], [0, -6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 10, -8, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0], [0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -11, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0], [-10, 0, 0, 0, 5, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -7, 0, 0, 0, 9, 2, 0, 0, 0, 0, 5, 5, 0], [0, 0, 0, 0, 3, -7, 0, 0, 0, -4, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -5, -4, 4, 0, 0, 0], [0, 10, 0, -4, 0, 0, -8, 0, 4, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 3, 0, 0, 0, 0, -5, 0, 0, 0, 0, 0, 0, 0], [0, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, -2, -2, 0, 0, 0], [0, 0, 0, 0, -1, 5, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0], [0, 0, 0, -2, 0, 0, 0, 0, -8, 0, 0, 0, 0, 0, 0, 0], [0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -2, -2, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2], [0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0], [0, -4, 0, 2, 0, 0, 4, 0, -2, 0, 0, 0, 0, 4, -4, -4], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 2, -2, 0, 0, 0], [0, 0, 0, 0, 3, 3, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0], [0, 0, 0, 7, 0, 0, 0, -9, -2, 0, 0, 0, 0, -5, -5, 0], [0, -4, 0, -1, 0, 0, -2, 0, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 4, 0, 0, 0, -9, -5, 0, 0, 0, 0, 1, 1, 0], [0, 0, 0, -5, 0, 0, 0, 0, -13, 0, 0, 0, 0, 0, 0, 0], [0, 2, 0, -1, 0, 0, -2, 0, 1, 0, 0, 0, 0, -2, 2, 2], [0, -2, 0, 1, 0, 0, 2, 0, -1, 0, 0, 0, 0, 2, -2, -1], [0, 0, 0, -6, 0, 0, 0, 11, 5, 0, 0, 0, 0, 1, 1, 0], [0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, -3, -3, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 2, -2, 0, 0, 0], [0, 0, 0, -12, 0, 0, 0, 0, -4, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -6, -4, 0, 0, 0, -10, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 4, 4, 0, 0, 0, 0, -4, -4, 0], [0, 0, 0, -4, 0, 0, 0, 9, 5, 0, 0, 0, 0, -1, -1, 0], [0, 0, 0, 1, 0, 0, 2, 0, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, -3, 0, 0, 0], [0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, -2, -2, 0, 0, 0], [0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0, 0], [0, 0, 0, 0, -7, 1, 0, 0, 0, -6, 0, 0, 0, 0, 0, 0], [0, 0, -5, 0, 0, 0, 0, 0, 0, 0, 0, -2, -2, 0, 0, 0], [0, 0, 0, 0, -7, 3, 0, 0, 0, -4, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -5, 7, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0], [0, -2, 0, 1, 0, 0, 2, 0, -1, 0, 0, 0, 0, 2, -2, 2], [0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0], [0, 0, 0, 5, 0, 0, 0, -4, 1, 0, 0, 0, 0, -6, -6, 0], [0, 6, 0, -3, 0, 0, -6, 0, 3, 0, 0, 0, 0, -6, 6, 1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -14, -2, 2, 0, 0, 0], [0, 0, -5, 0, 0, 0, 0, 0, 0, 0, 0, -2, -2, 0, 0, 0], [0, 2, 0, -1, 0, 0, -2, 0, 1, 0, 0, 0, 0, -2, 2, 5], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0], [0, 0, 0, 0, 7, -7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-4, 0, 0, 0, 5, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 8, 0, -7, 0, 0, -14, 0, 7, 0, 0, 0, 0, 0, 0, 0], [0, -4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 7, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0], [12, 0, 0, 0, -13, -13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [22, 0, 0, 0, -18, -18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 21, 0, 0, 0, 0, -7, 0, 0, 0, 0, 0, 0, 0], [0, -6, 0, 8, 0, 0, 16, 0, -8, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, 5, -5, 0, 0, 0], [0, 16, 0, 2, 0, 0, 4, 0, -2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 13, -7, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0], [0, 2, 0, -1, 0, 0, -2, 0, 1, 0, 0, 0, 0, -2, 2, -1], [0, -6, 0, 7, 0, 0, 14, 0, -7, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 15, 0, 0, 0, 0, -17, 0, 0, 0, 0, 0, 0, 0], [28, 0, 0, 0, 9, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -23, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0], [18, 0, 0, 0, 9, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -7, 7, 0, 0, 0], [0, -14, 0, 2, 0, 0, 4, 0, -2, 0, 0, 0, 0, 0, 0, 0], [0, -6, 0, 3, 0, 0, 6, 0, -3, 0, 0, 0, 0, 6, -6, -1], [16, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, -4, 0, 0, 0], [0, 4, 0, -5, 0, 0, -10, 0, 5, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 9, -15, 0, 0, 0, -6, 0, 0, 0, 0, 0, 0], [12, 0, 0, 0, -6, -6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -2, 0, 1, 0, 0, 2, 0, -1, 0, 0, 0, 0, 2, -2, 0], [-20, 0, 0, 0, 4, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -2, 8, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0], [0, 0, 0, 7, 0, 0, 0, -7, 0, 0, 0, 0, 0, -7, -7, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -9, -3, 3, 0, 0, 0], [0, 0, 0, -6, 0, 0, 0, 12, 6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -11, 0, 0, 0, 0, -11, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -6, -3, 3, 0, 0, 0], [0, 2, 0, -1, 0, 0, -2, 0, 1, 0, 0, 0, 0, -2, 2, -1], [0, -4, 0, 6, 0, 0, 12, 0, -6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -15, 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, -4, 4, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, -3, 0, 0, 0], [0, 0, 0, 0, 12, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -4, 0, 0, 0, -2, -6, 0, 0, 0, 0, 10, 10, 0]]
